AlphaXBodyEncoding enum

Selects how a method parameter becomes an AlphaXBody.

Inheritance
Available extensions

Values

json → const AlphaXBodyEncoding

Encode the value as JSON, using toJson() for non-JSON-safe objects.

text → const AlphaXBodyEncoding

Encode a String as text.

bytes → const AlphaXBodyEncoding

Encode an iterable of bytes.

stream → const AlphaXBodyEncoding

Use a caller-owned Stream<List<int>>.

file → const AlphaXBodyEncoding

Use a caller-owned AlphaXFileSource.

multipart → const AlphaXBodyEncoding

Use a caller-owned AlphaXMultipartBody.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AlphaXBodyEncoding>
A constant List of the values in this enum, in order of their declaration.