AlphaXBodyParam class final

Binds one method parameter to the request body.

The annotation is named AlphaXBodyParam to avoid colliding with the runtime AlphaXBody and AlphaXRequestBody alias exported by package:alphax/alphax.dart.

Constructors

AlphaXBodyParam({AlphaXBodyEncoding encoding = AlphaXBodyEncoding.json, String? contentType})
Creates request-body metadata.
const

Properties

contentType String?
Optional content type for text, bytes, stream, or file bodies.
final
encoding AlphaXBodyEncoding
Body representation to construct.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited