AlphaXPath class final

Binds a method parameter to a URI path placeholder.

Constructors

AlphaXPath(String name)
Creates a path binding for name.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
Placeholder name, without braces.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited