AlphaXQuery class final

Binds a method parameter to a repeated-safe URI query value.

Constructors

AlphaXQuery(String name)
Creates a query binding for name.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
Query parameter name.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited