AlphaXAppClient.borrowed constructor

AlphaXAppClient.borrowed(
  1. AlphaXClient client, {
  2. required String baseUrl,
  3. Duration? timeout,
})

Creates a facade that borrows client without closing it.

Calling close still makes this facade reject later requests, but it leaves the supplied client and its transport available to its owner.

Implementation

AlphaXAppClient.borrowed(
  AlphaXClient client, {
  required String baseUrl,
  Duration? timeout,
}) : this._(
       client,
       baseUrl: baseUrl,
       timeout: timeout,
       ownsClient: false,
     );