manualPingPong property
Whether the caller can manually send or observe ping/pong control frames.
Implementation
final AlphaXSupport manualPingPong;
Whether the caller can manually send or observe ping/pong control frames.
final AlphaXSupport manualPingPong;