negotiatedSubprotocolReporting property
Whether the selected subprotocol is reported by the provider.
Implementation
final AlphaXSupport negotiatedSubprotocolReporting;
Whether the selected subprotocol is reported by the provider.
final AlphaXSupport negotiatedSubprotocolReporting;