subprotocolNegotiation property
Whether requested subprotocols can be offered to the peer.
Implementation
final AlphaXSupport subprotocolNegotiation;
Whether requested subprotocols can be offered to the peer.
final AlphaXSupport subprotocolNegotiation;