origin property
Whether the close was initiated locally, by the peer, or by an error.
Implementation
final AlphaXWebSocketCloseOrigin origin;
Whether the close was initiated locally, by the peer, or by an error.
final AlphaXWebSocketCloseOrigin origin;