AlphaXWebSocketMessage class sealed
A complete text or binary message received from or sent to a WebSocket.
- Implementers
Constructors
-
AlphaXWebSocketMessage.binary(List<
int> bytes) -
Creates a binary message. The input bytes are copied.
factory
- AlphaXWebSocketMessage.text(String text)
-
Creates a text message.
constfactory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited