AlphaXWebSocketState enum
The lifecycle state of an AlphaX WebSocket session.
Values
- connecting → const AlphaXWebSocketState
-
The connector is establishing a session. A session object is not returned while it is in this state.
- open → const AlphaXWebSocketState
-
The session can send and receive messages.
- closing → const AlphaXWebSocketState
-
A local close has started and the session is waiting for termination.
- closed → const AlphaXWebSocketState
-
The session is terminal and cannot be reopened.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
AlphaXWebSocketState> - A constant List of the values in this enum, in order of their declaration.