AlphaXWebSocketTextMessage class final

A WebSocket text message.

Inheritance

Constructors

AlphaXWebSocketTextMessage(String text)
Creates a text message.
const

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
UTF-16 Dart text represented by the message.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override