AlphaXCookie class final
A transport-neutral HTTP cookie.
Constructors
Properties
- domain → String
-
Normalized host/domain scope.
final
- expires → DateTime?
-
Absolute expiry, when present.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- headerValue → String
-
Header representation.
no setter
- hostOnly → bool
-
Whether the cookie came from a host-only Set-Cookie value.
final
- httpOnly → bool
-
Whether the cookie was marked HttpOnly.
final
- name → String
-
Cookie name.
final
- path → String
-
Path scope.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secure → bool
-
Whether the cookie is sent only over HTTPS.
final
- value → String
-
Cookie value.
final
Methods
-
isExpired(
[DateTime? now]) → bool -
Whether the cookie is expired at
now. -
matches(
Uri uri, {DateTime? now}) → bool -
Whether this cookie applies to
uri. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited