AlphaXTimeoutKind enum
Timeout phase understood by the AlphaX public contract.
Values
- connect → const AlphaXTimeoutKind
-
DNS, socket, and TLS connection establishment.
- request → const AlphaXTimeoutKind
-
Request dispatch through response headers, including request upload.
- read → const AlphaXTimeoutKind
-
Maximum inactivity between response body chunks.
- overall → const AlphaXTimeoutKind
-
End-to-end request lifetime through response completion.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
AlphaXTimeoutKind> - A constant List of the values in this enum, in order of their declaration.