HttpMethod enum
HTTP methods supported by the AlphaX 1.0 request contract.
Values
- get → const HttpMethod
-
Retrieves a representation of a resource.
const HttpMethod('GET') - post → const HttpMethod
-
Creates or submits a representation.
const HttpMethod('POST') - put → const HttpMethod
-
Replaces a representation.
const HttpMethod('PUT') - patch → const HttpMethod
-
Partially updates a representation.
const HttpMethod('PATCH') - delete → const HttpMethod
-
Removes a representation.
const HttpMethod('DELETE') - head → const HttpMethod
-
Retrieves response metadata without a response body.
const HttpMethod('HEAD') - options → const HttpMethod
-
Requests communication options for a resource or server.
const HttpMethod('OPTIONS')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
Wire-format method token.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
parse(
String value) → HttpMethod - Parses a case-insensitive HTTP method token.
-
tryParse(
String value) → HttpMethod? -
Returns the parsed method or
nullfor an unsupported token.
Constants
-
values
→ const List<
HttpMethod> - A constant List of the values in this enum, in order of their declaration.