AlphaXWebSocketCloseInfo class final
Information available when an AlphaX WebSocket session terminates.
code and reason remain null when the provider did not report them.
AlphaX does not invent a normal close code for an abnormal termination.
Constructors
- AlphaXWebSocketCloseInfo({required AlphaXWebSocketCloseOrigin origin, int? code, String? reason})
-
Creates terminal close information.
const
Properties
- code → int?
-
The provider-reported or locally requested close code, when available.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- origin → AlphaXWebSocketCloseOrigin
-
Whether the close was initiated locally, by the peer, or by an error.
final
- reason → String?
-
The provider-reported or locally requested close reason, when available.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override